#!/usr/bin/env python
# coding: utf-8
#
#       Copyright 2008 Olivier Berten <olivier.berten@gmail.com>
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 3 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.
#

import gettext
from PyQt4.QtCore import *
from PyQt4.QtGui import *

from swatchbook import *
import swatchbook.codecs as codecs
import swatchbook.websvc as websvc

VERSION = "0.7.6"

def translate_sb(app,settings,main_globals):
	locale = settings.value("Language").toString() or QLocale.system().name()
	# translation of the app
	try:
		if os.path.isdir(os.path.join((dirpath(__file__) or "."),"locale")):
			lang = gettext.translation('swatchbooker', 'locale', languages=[str(locale)])
		elif os.name == 'nt' and os.path.isdir(os.path.join(sys.prefix,"share","locale")):
			lang = gettext.translation('swatchbooker', os.path.join(sys.prefix,"share","locale"), languages=[str(locale)])
		else:
			lang = gettext.translation('swatchbooker', None, languages=[str(locale)])
		lang.install()
		def _(msgid):
			return lang.gettext(msgid).decode('utf-8')

		def n_(msgid0,msgid1,n):
			return lang.ngettext(msgid0,msgid1,n).decode('utf-8')
	except IOError:
		def _(msgid):
			return gettext.gettext(msgid).decode('utf-8')

		def n_(msgid0,msgid1,n):
			return gettext.ngettext(msgid0,msgid1,n).decode('utf-8')

	main_globals['_'] = _
	main_globals['n_'] = n_
	globals()['_'] = _
	globals()['n_'] = n_

	# translation of the built-in dialogs
	qtTranslator = QTranslator()
	if qtTranslator.load("qt_" + locale, QLibraryInfo.location(QLibraryInfo.TranslationsPath)):
		app.installTranslator(qtTranslator)

class webOpenDlg(QDialog):
	def __init__(self, parent, settings, multi=False):
		super(webOpenDlg, self).__init__(parent)

		self.svc = False
		self.ids = False
		
		self.settings = settings
		self.multi = multi

		self.webSvcStack = QStackedWidget()
		self.webSvcList = QListWidget(self)
		palette = self.webSvcList.palette()
		palette.setColor(QPalette.Base,Qt.transparent)
		self.webSvcList.setPalette(palette)
		self.webSvcList.setFrameShape(QFrame.NoFrame)
		aboutBox = QGroupBox(_("About"))
		self.about = QLabel()
		self.about.setWordWrap(True)
		self.about.setOpenExternalLinks(True)
		aboutBoxLayout = QVBoxLayout()
		aboutBoxLayout.addWidget(self.about)
		aboutBox.setLayout(aboutBoxLayout)

		self.webWidgets = {}

		for svc in websvc.list:
			current_svc = eval('websvc.'+svc+'()')
			if 'swatchbook' in current_svc.content:
				webWidget = webWidgetList(svc,self)
			else:
				continue
			self.webSvcStack.addWidget(webWidget)
			listItem = QListWidgetItem(websvc.list[svc],self.webSvcList)
			listItem.setData(Qt.UserRole,svc)
			icon = os.path.join(dirpath(websvc.__file__) or '.',svc+'.png')
			if(QFile.exists(icon)):
				listItem.setIcon(QIcon(icon))
			self.webWidgets[svc] = (webWidget,current_svc.about,listItem)
		buttonBox = QDialogButtonBox(QDialogButtonBox.Ok|QDialogButtonBox.Cancel)
		self.webSvcList.sortItems()
		if settings.contains('lastWebSvc') and str(settings.value('lastWebSvc').toString()) in self.webWidgets:
			self.webSvcList.setCurrentItem(self.webWidgets[str(settings.value('lastWebSvc').toString())][2])
		else:
			self.webSvcList.setCurrentRow(0)
		self.changeTab()

		web1 = QWidget()
		web1l = QGridLayout()
		web1l.setContentsMargins(0,0,0,0)
		web1l.setSpacing(0)
		web1l.addWidget(self.webSvcList,0,0)
		web1l.addWidget(self.webSvcStack,0,1)
		web1.setLayout(web1l)

		webl = QGridLayout()
		webl.addWidget(web1,0,0,Qt.AlignTop)
		webl.addWidget(aboutBox,0,1,Qt.AlignTop)
		webl.addWidget(buttonBox,1,0,1,3)
		self.setLayout(webl)

		if self.multi:
			self.setWindowTitle(_("Add from web"))
		else:
			self.setWindowTitle(_("Open from web"))
		self.connect(self.webSvcList,
				SIGNAL("itemSelectionChanged()"), self.changeTab)
		self.connect(buttonBox, SIGNAL("accepted()"), self, SLOT("accept()"))
		self.connect(buttonBox, SIGNAL("rejected()"), self, SLOT("reject()"))

	def changeTab(self):
		self.svc = str(self.webSvcList.selectedItems()[0].data(Qt.UserRole).toString())
		self.ids = False
		self.webSvcStack.setCurrentWidget(self.webWidgets[self.svc][0])
		self.about.setText(self.webWidgets[self.svc][1])
		self.webSvcStack.currentWidget().load()
		self.webSvcList.setCurrentItem(self.webSvcList.selectedItems()[0],QItemSelectionModel.Current)
		self.settings.setValue('lastWebSvc',QVariant(self.svc))

class webWidgetList(QTreeWidget):
	def __init__(self, svc, parent=None):
		super(webWidgetList, self).__init__(parent)
		self.loaded = False
		self.parent = parent
		self.svc = eval('websvc.'+svc+'()')
		self.setHeaderHidden(True)
		self.setColumnHidden(1,True)
		self.setFrameShape(QFrame.NoFrame)
		if parent.multi:
			self.setSelectionMode(QAbstractItemView.ExtendedSelection)
		self.connect(self,
				SIGNAL("itemSelectionChanged()"), self.activate)
		self.connect(self,
				SIGNAL("itemExpanded(QTreeWidgetItem *)"), self.nextLevel)

	def activate(self):
		self.parent.ids = False
		if self.selectedItems():
			self.parent.ids = []
			for item in self.selectedItems():
				self.parent.ids.append(unicode(item.text(1)))

	def load(self):
		if not self.loaded:
			try:
				root = self.svc.level0()
			except IOError:
				root = []
			for item in root:
				itemtext = QStringList()
				itemtext << root[item] << item
				titem = QTreeWidgetItem(self,itemtext)
				if self.svc.nbLevels > 1:
					titem.setChildIndicatorPolicy(QTreeWidgetItem.ShowIndicator)
					titem.setFlags(titem.flags() & ~(Qt.ItemIsSelectable))
			self.loaded = True

	def nextLevel(self,treeItem):
		if treeItem.childCount() == 0:
			level = 1
			parent = treeItem.parent()
			while parent:
				parent = parent.parent()
				level += 1
			llist = eval('self.svc.level'+str(level))(unicode(treeItem.text(1)))
			for item in llist:
				itemtext = QStringList()
				itemtext << llist[item] << item
				titem = QTreeWidgetItem(treeItem,itemtext)
				if self.svc.nbLevels > level+1:
					titem.setChildIndicatorPolicy(QTreeWidgetItem.ShowIndicator)
					titem.setFlags(titem.flags() & ~(Qt.ItemIsSelectable))

qt_resource_data = "\
\x00\x00\x2d\x5c\
\x3c\
\x3f\x78\x6d\x6c\x20\x76\x65\x72\x73\x69\x6f\x6e\x3d\x22\x31\x2e\
\x30\x22\x20\x65\x6e\x63\x6f\x64\x69\x6e\x67\x3d\x22\x55\x54\x46\
\x2d\x38\x22\x20\x73\x74\x61\x6e\x64\x61\x6c\x6f\x6e\x65\x3d\x22\
\x6e\x6f\x22\x3f\x3e\x0a\x3c\x21\x2d\x2d\x20\x43\x72\x65\x61\x74\
\x65\x64\x20\x77\x69\x74\x68\x20\x49\x6e\x6b\x73\x63\x61\x70\x65\
\x20\x28\x68\x74\x74\x70\x3a\x2f\x2f\x77\x77\x77\x2e\x69\x6e\x6b\
\x73\x63\x61\x70\x65\x2e\x6f\x72\x67\x2f\x29\x20\x2d\x2d\x3e\x0a\
\x0a\x3c\x73\x76\x67\x0a\x20\x20\x20\x78\x6d\x6c\x6e\x73\x3a\x64\
\x63\x3d\x22\x68\x74\x74\x70\x3a\x2f\x2f\x70\x75\x72\x6c\x2e\x6f\
\x72\x67\x2f\x64\x63\x2f\x65\x6c\x65\x6d\x65\x6e\x74\x73\x2f\x31\
\x2e\x31\x2f\x22\x0a\x20\x20\x20\x78\x6d\x6c\x6e\x73\x3a\x63\x63\
\x3d\x22\x68\x74\x74\x70\x3a\x2f\x2f\x63\x72\x65\x61\x74\x69\x76\
\x65\x63\x6f\x6d\x6d\x6f\x6e\x73\x2e\x6f\x72\x67\x2f\x6e\x73\x23\
\x22\x0a\x20\x20\x20\x78\x6d\x6c\x6e\x73\x3a\x72\x64\x66\x3d\x22\
\x68\x74\x74\x70\x3a\x2f\x2f\x77\x77\x77\x2e\x77\x33\x2e\x6f\x72\
\x67\x2f\x31\x39\x39\x39\x2f\x30\x32\x2f\x32\x32\x2d\x72\x64\x66\
\x2d\x73\x79\x6e\x74\x61\x78\x2d\x6e\x73\x23\x22\x0a\x20\x20\x20\
\x78\x6d\x6c\x6e\x73\x3a\x73\x76\x67\x3d\x22\x68\x74\x74\x70\x3a\
\x2f\x2f\x77\x77\x77\x2e\x77\x33\x2e\x6f\x72\x67\x2f\x32\x30\x30\
\x30\x2f\x73\x76\x67\x22\x0a\x20\x20\x20\x78\x6d\x6c\x6e\x73\x3d\
\x22\x68\x74\x74\x70\x3a\x2f\x2f\x77\x77\x77\x2e\x77\x33\x2e\x6f\
\x72\x67\x2f\x32\x30\x30\x30\x2f\x73\x76\x67\x22\x0a\x20\x20\x20\
\x78\x6d\x6c\x6e\x73\x3a\x78\x6c\x69\x6e\x6b\x3d\x22\x68\x74\x74\
\x70\x3a\x2f\x2f\x77\x77\x77\x2e\x77\x33\x2e\x6f\x72\x67\x2f\x31\
\x39\x39\x39\x2f\x78\x6c\x69\x6e\x6b\x22\x0a\x20\x20\x20\x78\x6d\
\x6c\x6e\x73\x3a\x73\x6f\x64\x69\x70\x6f\x64\x69\x3d\x22\x68\x74\
\x74\x70\x3a\x2f\x2f\x73\x6f\x64\x69\x70\x6f\x64\x69\x2e\x73\x6f\
\x75\x72\x63\x65\x66\x6f\x72\x67\x65\x2e\x6e\x65\x74\x2f\x44\x54\
\x44\x2f\x73\x6f\x64\x69\x70\x6f\x64\x69\x2d\x30\x2e\x64\x74\x64\
\x22\x0a\x20\x20\x20\x78\x6d\x6c\x6e\x73\x3a\x69\x6e\x6b\x73\x63\
\x61\x70\x65\x3d\x22\x68\x74\x74\x70\x3a\x2f\x2f\x77\x77\x77\x2e\
\x69\x6e\x6b\x73\x63\x61\x70\x65\x2e\x6f\x72\x67\x2f\x6e\x61\x6d\
\x65\x73\x70\x61\x63\x65\x73\x2f\x69\x6e\x6b\x73\x63\x61\x70\x65\
\x22\x0a\x20\x20\x20\x77\x69\x64\x74\x68\x3d\x22\x36\x34\x22\x0a\
\x20\x20\x20\x68\x65\x69\x67\x68\x74\x3d\x22\x36\x34\x22\x0a\x20\
\x20\x20\x69\x64\x3d\x22\x73\x76\x67\x32\x22\x0a\x20\x20\x20\x73\
\x6f\x64\x69\x70\x6f\x64\x69\x3a\x76\x65\x72\x73\x69\x6f\x6e\x3d\
\x22\x30\x2e\x33\x32\x22\x0a\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\
\x70\x65\x3a\x76\x65\x72\x73\x69\x6f\x6e\x3d\x22\x30\x2e\x34\x37\
\x70\x72\x65\x31\x20\x72\x32\x31\x37\x32\x30\x22\x0a\x20\x20\x20\
\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x64\x6f\x63\x6e\x61\x6d\x65\
\x3d\x22\x73\x77\x61\x74\x63\x68\x62\x6f\x6f\x6b\x65\x72\x2e\x73\
\x76\x67\x22\x0a\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\
\x6f\x75\x74\x70\x75\x74\x5f\x65\x78\x74\x65\x6e\x73\x69\x6f\x6e\
\x3d\x22\x6f\x72\x67\x2e\x69\x6e\x6b\x73\x63\x61\x70\x65\x2e\x6f\
\x75\x74\x70\x75\x74\x2e\x73\x76\x67\x2e\x69\x6e\x6b\x73\x63\x61\
\x70\x65\x22\x0a\x20\x20\x20\x76\x65\x72\x73\x69\x6f\x6e\x3d\x22\
\x31\x2e\x30\x22\x3e\x0a\x20\x20\x3c\x64\x65\x66\x73\x0a\x20\x20\
\x20\x20\x20\x69\x64\x3d\x22\x64\x65\x66\x73\x34\x22\x3e\x0a\x20\
\x20\x20\x20\x3c\x6c\x69\x6e\x65\x61\x72\x47\x72\x61\x64\x69\x65\
\x6e\x74\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x6c\x69\
\x6e\x65\x61\x72\x47\x72\x61\x64\x69\x65\x6e\x74\x33\x39\x39\x33\
\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x73\x74\x6f\x70\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x73\
\x74\x6f\x70\x2d\x63\x6f\x6c\x6f\x72\x3a\x23\x66\x66\x66\x66\x66\
\x66\x3b\x73\x74\x6f\x70\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\
\x3b\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x6f\x66\x66\x73\
\x65\x74\x3d\x22\x30\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x69\x64\x3d\x22\x73\x74\x6f\x70\x33\x39\x39\x35\x22\x20\x2f\x3e\
\x0a\x20\x20\x20\x20\x20\x20\x3c\x73\x74\x6f\x70\x0a\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x73\x74\x6f\
\x70\x2d\x63\x6f\x6c\x6f\x72\x3a\x23\x63\x34\x63\x34\x63\x34\x3b\
\x73\x74\x6f\x70\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x6f\x66\x66\x73\x65\x74\
\x3d\x22\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\
\x3d\x22\x73\x74\x6f\x70\x33\x39\x39\x37\x22\x20\x2f\x3e\x0a\x20\
\x20\x20\x20\x3c\x2f\x6c\x69\x6e\x65\x61\x72\x47\x72\x61\x64\x69\
\x65\x6e\x74\x3e\x0a\x20\x20\x20\x20\x3c\x69\x6e\x6b\x73\x63\x61\
\x70\x65\x3a\x70\x65\x72\x73\x70\x65\x63\x74\x69\x76\x65\x0a\x20\
\x20\x20\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x74\
\x79\x70\x65\x3d\x22\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x70\x65\
\x72\x73\x70\x33\x64\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\
\x6b\x73\x63\x61\x70\x65\x3a\x76\x70\x5f\x78\x3d\x22\x30\x20\x3a\
\x20\x35\x32\x36\x2e\x31\x38\x31\x30\x39\x20\x3a\x20\x31\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\
\x76\x70\x5f\x79\x3d\x22\x36\x2e\x31\x32\x33\x30\x33\x31\x38\x65\
\x2d\x31\x34\x20\x3a\x20\x31\x30\x30\x30\x20\x3a\x20\x30\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\
\x76\x70\x5f\x7a\x3d\x22\x37\x34\x34\x2e\x30\x39\x34\x34\x38\x20\
\x3a\x20\x35\x32\x36\x2e\x31\x38\x31\x30\x39\x20\x3a\x20\x31\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\
\x3a\x70\x65\x72\x73\x70\x33\x64\x2d\x6f\x72\x69\x67\x69\x6e\x3d\
\x22\x33\x37\x32\x2e\x30\x34\x37\x32\x34\x20\x3a\x20\x33\x35\x30\
\x2e\x37\x38\x37\x33\x39\x20\x3a\x20\x31\x22\x0a\x20\x20\x20\x20\
\x20\x20\x20\x69\x64\x3d\x22\x70\x65\x72\x73\x70\x65\x63\x74\x69\
\x76\x65\x31\x30\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x3c\x69\x6e\
\x6b\x73\x63\x61\x70\x65\x3a\x70\x65\x72\x73\x70\x65\x63\x74\x69\
\x76\x65\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x70\x65\
\x72\x73\x70\x65\x63\x74\x69\x76\x65\x33\x35\x30\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x70\x65\
\x72\x73\x70\x33\x64\x2d\x6f\x72\x69\x67\x69\x6e\x3d\x22\x33\x31\
\x32\x2e\x35\x20\x3a\x20\x33\x37\x39\x2e\x31\x36\x36\x36\x37\x20\
\x3a\x20\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\
\x63\x61\x70\x65\x3a\x76\x70\x5f\x7a\x3d\x22\x36\x32\x35\x20\x3a\
\x20\x35\x36\x38\x2e\x37\x35\x20\x3a\x20\x31\x22\x0a\x20\x20\x20\
\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x76\x70\x5f\
\x79\x3d\x22\x30\x20\x3a\x20\x31\x30\x30\x30\x20\x3a\x20\x30\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\
\x3a\x76\x70\x5f\x78\x3d\x22\x30\x20\x3a\x20\x35\x36\x38\x2e\x37\
\x35\x20\x3a\x20\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x73\x6f\
\x64\x69\x70\x6f\x64\x69\x3a\x74\x79\x70\x65\x3d\x22\x69\x6e\x6b\
\x73\x63\x61\x70\x65\x3a\x70\x65\x72\x73\x70\x33\x64\x22\x20\x2f\
\x3e\x0a\x20\x20\x20\x20\x3c\x72\x61\x64\x69\x61\x6c\x47\x72\x61\
\x64\x69\x65\x6e\x74\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\
\x73\x63\x61\x70\x65\x3a\x63\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\
\x6c\x77\x61\x79\x73\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x78\x6c\
\x69\x6e\x6b\x3a\x68\x72\x65\x66\x3d\x22\x23\x6c\x69\x6e\x65\x61\
\x72\x47\x72\x61\x64\x69\x65\x6e\x74\x33\x39\x39\x33\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x72\x61\x64\x69\x61\x6c\
\x47\x72\x61\x64\x69\x65\x6e\x74\x34\x30\x33\x33\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x67\x72\x61\x64\x69\x65\x6e\x74\x55\x6e\x69\
\x74\x73\x3d\x22\x75\x73\x65\x72\x53\x70\x61\x63\x65\x4f\x6e\x55\
\x73\x65\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x63\x78\x3d\x22\x31\
\x35\x39\x2e\x36\x30\x34\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x63\x79\x3d\x22\x34\x39\x30\x2e\x33\x39\x33\x33\x34\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x66\x78\x3d\x22\x31\x35\x39\x2e\x36\x30\
\x34\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x66\x79\x3d\x22\x34\
\x39\x30\x2e\x33\x39\x33\x33\x34\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x72\x3d\x22\x33\x36\x2e\x37\x38\x37\x34\x34\x39\x22\x20\x2f\
\x3e\x0a\x20\x20\x20\x20\x3c\x66\x69\x6c\x74\x65\x72\x0a\x20\x20\
\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x6f\
\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\x69\x6c\x74\x65\x72\
\x34\x31\x32\x32\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x63\x6f\x6c\
\x6f\x72\x2d\x69\x6e\x74\x65\x72\x70\x6f\x6c\x61\x74\x69\x6f\x6e\
\x2d\x66\x69\x6c\x74\x65\x72\x73\x3d\x22\x73\x52\x47\x42\x22\x3e\
\x0a\x20\x20\x20\x20\x20\x20\x3c\x66\x65\x47\x61\x75\x73\x73\x69\
\x61\x6e\x42\x6c\x75\x72\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x6f\x6c\x6c\x65\x63\x74\
\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x73\x74\x64\x44\x65\x76\x69\x61\x74\x69\x6f\x6e\x3d\
\x22\x37\x2e\x32\x35\x38\x39\x33\x31\x31\x22\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\x65\x47\x61\x75\x73\x73\
\x69\x61\x6e\x42\x6c\x75\x72\x34\x31\x32\x34\x22\x20\x2f\x3e\x0a\
\x20\x20\x20\x20\x3c\x2f\x66\x69\x6c\x74\x65\x72\x3e\x0a\x20\x20\
\x20\x20\x3c\x66\x69\x6c\x74\x65\x72\x0a\x20\x20\x20\x20\x20\x20\
\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x6f\x6c\x6c\x65\x63\
\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x69\x64\x3d\x22\x66\x69\x6c\x74\x65\x72\x34\x31\x32\x36\
\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x63\x6f\x6c\x6f\x72\x2d\x69\
\x6e\x74\x65\x72\x70\x6f\x6c\x61\x74\x69\x6f\x6e\x2d\x66\x69\x6c\
\x74\x65\x72\x73\x3d\x22\x73\x52\x47\x42\x22\x3e\x0a\x20\x20\x20\
\x20\x20\x20\x3c\x66\x65\x47\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\
\x75\x72\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\
\x63\x61\x70\x65\x3a\x63\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\
\x77\x61\x79\x73\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\
\x74\x64\x44\x65\x76\x69\x61\x74\x69\x6f\x6e\x3d\x22\x36\x2e\x36\
\x30\x34\x37\x31\x30\x33\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x69\x64\x3d\x22\x66\x65\x47\x61\x75\x73\x73\x69\x61\x6e\x42\
\x6c\x75\x72\x34\x31\x32\x38\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\
\x3c\x2f\x66\x69\x6c\x74\x65\x72\x3e\x0a\x20\x20\x20\x20\x3c\x66\
\x69\x6c\x74\x65\x72\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\
\x73\x63\x61\x70\x65\x3a\x63\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\
\x6c\x77\x61\x79\x73\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x64\
\x3d\x22\x66\x69\x6c\x74\x65\x72\x34\x31\x33\x30\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x63\x6f\x6c\x6f\x72\x2d\x69\x6e\x74\x65\x72\
\x70\x6f\x6c\x61\x74\x69\x6f\x6e\x2d\x66\x69\x6c\x74\x65\x72\x73\
\x3d\x22\x73\x52\x47\x42\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\
\x66\x65\x47\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\
\x3a\x63\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\
\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x64\x44\x65\
\x76\x69\x61\x74\x69\x6f\x6e\x3d\x22\x36\x2e\x36\x30\x34\x36\x39\
\x33\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\
\x22\x66\x65\x47\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x34\
\x31\x33\x32\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x3c\x2f\x66\x69\
\x6c\x74\x65\x72\x3e\x0a\x20\x20\x20\x20\x3c\x66\x69\x6c\x74\x65\
\x72\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\
\x65\x3a\x63\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\
\x73\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\x69\
\x6c\x74\x65\x72\x34\x31\x34\x36\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x63\x6f\x6c\x6f\x72\x2d\x69\x6e\x74\x65\x72\x70\x6f\x6c\x61\
\x74\x69\x6f\x6e\x2d\x66\x69\x6c\x74\x65\x72\x73\x3d\x22\x73\x52\
\x47\x42\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x66\x65\x47\x61\
\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x6f\x6c\
\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x73\x74\x64\x44\x65\x76\x69\x61\x74\
\x69\x6f\x6e\x3d\x22\x31\x2e\x31\x34\x34\x32\x32\x38\x39\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\x65\x47\
\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x34\x31\x34\x38\x22\
\x20\x2f\x3e\x0a\x20\x20\x20\x20\x3c\x2f\x66\x69\x6c\x74\x65\x72\
\x3e\x0a\x20\x20\x20\x20\x3c\x66\x69\x6c\x74\x65\x72\x0a\x20\x20\
\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x6f\
\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\x69\x6c\x74\x65\x72\
\x33\x36\x32\x37\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x66\x65\
\x47\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x0a\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\
\x6f\x6c\x6c\x65\x63\x74\x3d\x22\x61\x6c\x77\x61\x79\x73\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x64\x44\x65\x76\x69\
\x61\x74\x69\x6f\x6e\x3d\x22\x38\x2e\x37\x36\x35\x33\x38\x35\x35\
\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x66\
\x65\x47\x61\x75\x73\x73\x69\x61\x6e\x42\x6c\x75\x72\x33\x36\x32\
\x39\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x3c\x2f\x66\x69\x6c\x74\
\x65\x72\x3e\x0a\x20\x20\x3c\x2f\x64\x65\x66\x73\x3e\x0a\x20\x20\
\x3c\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x6e\x61\x6d\x65\x64\x76\
\x69\x65\x77\x0a\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x62\x61\x73\
\x65\x22\x0a\x20\x20\x20\x20\x20\x70\x61\x67\x65\x63\x6f\x6c\x6f\
\x72\x3d\x22\x23\x66\x66\x66\x66\x66\x66\x22\x0a\x20\x20\x20\x20\
\x20\x62\x6f\x72\x64\x65\x72\x63\x6f\x6c\x6f\x72\x3d\x22\x23\x36\
\x36\x36\x36\x36\x36\x22\x0a\x20\x20\x20\x20\x20\x62\x6f\x72\x64\
\x65\x72\x6f\x70\x61\x63\x69\x74\x79\x3d\x22\x31\x2e\x30\x22\x0a\
\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x70\x61\
\x67\x65\x6f\x70\x61\x63\x69\x74\x79\x3d\x22\x30\x2e\x30\x22\x0a\
\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x70\x61\
\x67\x65\x73\x68\x61\x64\x6f\x77\x3d\x22\x32\x22\x0a\x20\x20\x20\
\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x7a\x6f\x6f\x6d\x3d\
\x22\x35\x2e\x36\x35\x36\x38\x35\x34\x32\x22\x0a\x20\x20\x20\x20\
\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x63\x78\x3d\x22\x32\x30\
\x2e\x36\x30\x37\x34\x39\x39\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\
\x6b\x73\x63\x61\x70\x65\x3a\x63\x79\x3d\x22\x32\x32\x2e\x32\x39\
\x30\x35\x31\x38\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\
\x61\x70\x65\x3a\x64\x6f\x63\x75\x6d\x65\x6e\x74\x2d\x75\x6e\x69\
\x74\x73\x3d\x22\x70\x78\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\
\x73\x63\x61\x70\x65\x3a\x63\x75\x72\x72\x65\x6e\x74\x2d\x6c\x61\
\x79\x65\x72\x3d\x22\x67\x32\x37\x35\x33\x22\x0a\x20\x20\x20\x20\
\x20\x73\x68\x6f\x77\x67\x72\x69\x64\x3d\x22\x66\x61\x6c\x73\x65\
\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\
\x77\x69\x6e\x64\x6f\x77\x2d\x77\x69\x64\x74\x68\x3d\x22\x31\x32\
\x37\x32\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\
\x65\x3a\x77\x69\x6e\x64\x6f\x77\x2d\x68\x65\x69\x67\x68\x74\x3d\
\x22\x37\x32\x32\x22\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\
\x61\x70\x65\x3a\x77\x69\x6e\x64\x6f\x77\x2d\x78\x3d\x22\x30\x22\
\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x77\
\x69\x6e\x64\x6f\x77\x2d\x79\x3d\x22\x32\x35\x22\x0a\x20\x20\x20\
\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x77\x69\x6e\x64\x6f\
\x77\x2d\x6d\x61\x78\x69\x6d\x69\x7a\x65\x64\x3d\x22\x30\x22\x20\
\x2f\x3e\x0a\x20\x20\x3c\x6d\x65\x74\x61\x64\x61\x74\x61\x0a\x20\
\x20\x20\x20\x20\x69\x64\x3d\x22\x6d\x65\x74\x61\x64\x61\x74\x61\
\x37\x22\x3e\x0a\x20\x20\x20\x20\x3c\x72\x64\x66\x3a\x52\x44\x46\
\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x63\x63\x3a\x57\x6f\x72\x6b\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x72\x64\x66\x3a\x61\x62\
\x6f\x75\x74\x3d\x22\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x3c\x64\x63\x3a\x66\x6f\x72\x6d\x61\x74\x3e\x69\x6d\x61\x67\x65\
\x2f\x73\x76\x67\x2b\x78\x6d\x6c\x3c\x2f\x64\x63\x3a\x66\x6f\x72\
\x6d\x61\x74\x3e\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x3c\x64\x63\
\x3a\x74\x79\x70\x65\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x72\x64\x66\x3a\x72\x65\x73\x6f\x75\x72\x63\x65\x3d\x22\x68\
\x74\x74\x70\x3a\x2f\x2f\x70\x75\x72\x6c\x2e\x6f\x72\x67\x2f\x64\
\x63\x2f\x64\x63\x6d\x69\x74\x79\x70\x65\x2f\x53\x74\x69\x6c\x6c\
\x49\x6d\x61\x67\x65\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x3c\x64\x63\x3a\x74\x69\x74\x6c\x65\x20\x2f\x3e\x0a\x20\
\x20\x20\x20\x20\x20\x3c\x2f\x63\x63\x3a\x57\x6f\x72\x6b\x3e\x0a\
\x20\x20\x20\x20\x3c\x2f\x72\x64\x66\x3a\x52\x44\x46\x3e\x0a\x20\
\x20\x3c\x2f\x6d\x65\x74\x61\x64\x61\x74\x61\x3e\x0a\x20\x20\x3c\
\x67\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\
\x6c\x61\x62\x65\x6c\x3d\x22\x43\x61\x6c\x71\x75\x65\x20\x31\x22\
\x0a\x20\x20\x20\x20\x20\x69\x6e\x6b\x73\x63\x61\x70\x65\x3a\x67\
\x72\x6f\x75\x70\x6d\x6f\x64\x65\x3d\x22\x6c\x61\x79\x65\x72\x22\
\x0a\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x6c\x61\x79\x65\x72\x31\
\x22\x0a\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\
\x3d\x22\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x28\x30\x2c\x2d\x36\
\x33\x36\x29\x22\x3e\x0a\x20\x20\x20\x20\x3c\x67\x0a\x20\x20\x20\
\x20\x20\x20\x20\x69\x64\x3d\x22\x67\x32\x37\x35\x33\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\
\x22\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x28\x31\x39\x2e\x34\x31\
\x38\x39\x36\x36\x2c\x2d\x33\x32\x2e\x33\x32\x37\x31\x36\x31\x29\
\x22\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x70\x61\x74\x68\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x6f\
\x70\x61\x63\x69\x74\x79\x3a\x30\x2e\x34\x3b\x66\x69\x6c\x6c\x3a\
\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\x3a\x23\x30\x30\x30\
\x30\x30\x30\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x77\x69\x64\x74\x68\
\x3a\x35\x32\x2e\x32\x34\x32\x31\x39\x31\x33\x31\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\x6e\
\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\x69\
\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\x61\
\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\
\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\x30\
\x3b\x66\x69\x6c\x74\x65\x72\x3a\x75\x72\x6c\x28\x23\x66\x69\x6c\
\x74\x65\x72\x33\x36\x32\x37\x29\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x64\x3d\x22\x6d\x20\x33\x37\x36\x2e\x30\x31\x38\x35\
\x33\x2c\x31\x32\x30\x2e\x33\x32\x37\x31\x36\x20\x63\x20\x2d\x32\
\x35\x2e\x31\x37\x32\x37\x37\x2c\x30\x2e\x33\x38\x37\x38\x36\x20\
\x2d\x35\x30\x2e\x30\x30\x34\x32\x36\x2c\x31\x31\x2e\x33\x33\x30\
\x39\x20\x2d\x36\x37\x2e\x35\x33\x31\x32\x35\x2c\x33\x32\x2e\x32\
\x31\x38\x37\x35\x20\x6c\x20\x2d\x32\x36\x37\x2e\x33\x31\x32\x34\
\x39\x36\x2c\x33\x31\x38\x2e\x36\x32\x35\x20\x63\x20\x2d\x35\x2e\
\x36\x33\x33\x38\x32\x39\x2c\x36\x2e\x31\x32\x31\x35\x32\x20\x2d\
\x31\x30\x2e\x33\x37\x38\x33\x31\x39\x2c\x31\x33\x2e\x30\x30\x36\
\x35\x38\x20\x2d\x31\x34\x2e\x31\x32\x35\x2c\x32\x30\x2e\x34\x33\
\x37\x35\x20\x2d\x30\x2e\x32\x39\x34\x39\x38\x2c\x30\x2e\x35\x38\
\x31\x38\x35\x20\x2d\x30\x2e\x35\x39\x33\x36\x34\x31\x2c\x31\x2e\
\x31\x36\x33\x36\x39\x20\x2d\x30\x2e\x38\x37\x35\x2c\x31\x2e\x37\
\x35\x20\x2d\x30\x2e\x30\x33\x30\x30\x35\x2c\x30\x2e\x30\x36\x33\
\x20\x2d\x30\x2e\x30\x36\x33\x38\x34\x2c\x30\x2e\x31\x32\x34\x34\
\x36\x20\x2d\x30\x2e\x30\x39\x33\x37\x35\x2c\x30\x2e\x31\x38\x37\
\x35\x20\x2d\x30\x2e\x32\x38\x39\x39\x32\x37\x2c\x30\x2e\x36\x30\
\x37\x38\x20\x2d\x30\x2e\x35\x36\x38\x34\x31\x34\x2c\x31\x2e\x32\
\x33\x31\x34\x32\x20\x2d\x30\x2e\x38\x34\x33\x37\x35\x2c\x31\x2e\
\x38\x34\x33\x37\x35\x20\x2d\x30\x2e\x30\x31\x38\x39\x38\x2c\x30\
\x2e\x30\x34\x32\x35\x20\x2d\x30\x2e\x30\x34\x33\x35\x38\x2c\x30\
\x2e\x30\x38\x32\x35\x20\x2d\x30\x2e\x30\x36\x32\x35\x2c\x30\x2e\
\x31\x32\x35\x20\x2d\x30\x2e\x32\x38\x33\x35\x37\x34\x2c\x30\x2e\
\x36\x33\x33\x33\x20\x2d\x30\x2e\x35\x34\x34\x34\x39\x34\x2c\x31\
\x2e\x32\x36\x38\x33\x39\x20\x2d\x30\x2e\x38\x31\x32\x35\x2c\x31\
\x2e\x39\x30\x36\x32\x35\x20\x2d\x30\x2e\x30\x39\x34\x37\x31\x2c\
\x30\x2e\x32\x32\x36\x38\x33\x20\x2d\x30\x2e\x31\x38\x38\x33\x37\
\x36\x2c\x30\x2e\x34\x35\x39\x38\x31\x20\x2d\x30\x2e\x32\x38\x31\
\x32\x35\x2c\x30\x2e\x36\x38\x37\x35\x20\x2d\x30\x2e\x31\x38\x36\
\x37\x36\x34\x2c\x30\x2e\x34\x35\x34\x39\x38\x20\x2d\x30\x2e\x33\
\x38\x33\x36\x30\x33\x2c\x30\x2e\x39\x31\x37\x38\x38\x20\x2d\x30\
\x2e\x35\x36\x32\x35\x2c\x31\x2e\x33\x37\x35\x20\x2d\x30\x2e\x30\
\x30\x33\x35\x2c\x30\x2e\x30\x30\x39\x20\x30\x2e\x30\x30\x33\x35\
\x2c\x30\x2e\x30\x32\x32\x33\x20\x30\x2c\x30\x2e\x30\x33\x31\x32\
\x20\x2d\x30\x2e\x32\x36\x34\x35\x35\x38\x2c\x30\x2e\x36\x37\x36\
\x36\x36\x20\x2d\x30\x2e\x35\x33\x33\x39\x30\x35\x2c\x31\x2e\x33\
\x35\x30\x31\x37\x20\x2d\x30\x2e\x37\x38\x31\x32\x35\x2c\x32\x2e\
\x30\x33\x31\x32\x35\x20\x2d\x30\x2e\x32\x34\x35\x38\x35\x32\x2c\
\x30\x2e\x36\x38\x31\x32\x36\x20\x2d\x30\x2e\x34\x35\x37\x39\x31\
\x35\x2c\x31\x2e\x33\x34\x33\x32\x31\x20\x2d\x30\x2e\x36\x38\x37\
\x35\x2c\x32\x2e\x30\x33\x31\x32\x35\x20\x2d\x30\x2e\x31\x36\x30\
\x38\x36\x37\x2c\x30\x2e\x34\x37\x38\x37\x31\x20\x2d\x30\x2e\x33\
\x31\x36\x32\x36\x31\x2c\x30\x2e\x39\x35\x36\x39\x31\x20\x2d\x30\
\x2e\x34\x36\x38\x37\x35\x2c\x31\x2e\x34\x33\x37\x35\x20\x2d\x30\
\x2e\x30\x36\x38\x35\x33\x2c\x30\x2e\x32\x31\x37\x33\x39\x20\x2d\
\x30\x2e\x31\x35\x31\x38\x34\x39\x2c\x30\x2e\x34\x33\x38\x32\x33\
\x20\x2d\x30\x2e\x32\x31\x38\x37\x35\x2c\x30\x2e\x36\x35\x36\x32\
\x35\x20\x2d\x30\x2e\x30\x30\x32\x39\x2c\x30\x2e\x30\x30\x39\x20\
\x30\x2e\x30\x30\x32\x39\x2c\x30\x2e\x30\x32\x31\x38\x20\x30\x2c\
\x30\x2e\x30\x33\x31\x32\x20\x2d\x30\x2e\x30\x36\x30\x38\x39\x2c\
\x30\x2e\x31\x39\x38\x36\x35\x20\x2d\x30\x2e\x31\x32\x37\x39\x37\
\x2c\x30\x2e\x33\x39\x34\x35\x38\x20\x2d\x30\x2e\x31\x38\x37\x35\
\x2c\x30\x2e\x35\x39\x33\x37\x35\x20\x2d\x30\x2e\x33\x36\x30\x38\
\x31\x36\x2c\x31\x2e\x31\x39\x39\x35\x32\x20\x2d\x30\x2e\x36\x39\
\x30\x38\x37\x39\x2c\x32\x2e\x34\x31\x35\x36\x31\x20\x2d\x31\x2c\
\x33\x2e\x36\x32\x35\x20\x2d\x30\x2e\x31\x37\x33\x35\x35\x2c\x30\
\x2e\x36\x38\x34\x39\x34\x20\x2d\x30\x2e\x33\x34\x32\x34\x32\x39\
\x2c\x31\x2e\x33\x37\x32\x32\x20\x2d\x30\x2e\x35\x2c\x32\x2e\x30\
\x36\x32\x35\x20\x2d\x32\x2e\x39\x31\x39\x32\x31\x37\x2c\x31\x32\
\x2e\x36\x36\x30\x32\x35\x20\x2d\x33\x2e\x30\x33\x39\x36\x31\x33\
\x2c\x32\x35\x2e\x37\x33\x35\x36\x34\x20\x2d\x30\x2e\x34\x33\x37\
\x35\x2c\x33\x38\x2e\x33\x34\x33\x37\x35\x20\x30\x2e\x31\x33\x37\
\x32\x37\x35\x2c\x30\x2e\x36\x36\x35\x31\x34\x20\x30\x2e\x32\x38\
\x35\x30\x39\x38\x2c\x31\x2e\x33\x33\x37\x37\x34\x20\x30\x2e\x34\
\x33\x37\x35\x2c\x32\x20\x30\x2e\x30\x31\x33\x38\x39\x2c\x30\x2e\
\x30\x36\x31\x33\x20\x30\x2e\x30\x31\x37\x32\x34\x2c\x30\x2e\x31\
\x32\x36\x32\x20\x30\x2e\x30\x33\x31\x32\x35\x2c\x30\x2e\x31\x38\
\x37\x35\x20\x30\x2e\x30\x31\x39\x33\x2c\x30\x2e\x30\x38\x33\x31\
\x20\x30\x2e\x30\x34\x32\x39\x36\x2c\x30\x2e\x31\x36\x36\x39\x38\
\x20\x30\x2e\x30\x36\x32\x35\x2c\x30\x2e\x32\x35\x20\x30\x2e\x31\
\x34\x33\x32\x30\x34\x2c\x30\x2e\x36\x31\x38\x31\x36\x20\x30\x2e\
\x33\x31\x32\x37\x31\x37\x2c\x31\x2e\x32\x32\x39\x39\x31\x20\x30\
\x2e\x34\x36\x38\x37\x35\x2c\x31\x2e\x38\x34\x33\x37\x35\x20\x30\
\x2e\x30\x32\x31\x34\x37\x2c\x30\x2e\x30\x38\x33\x33\x20\x30\x2e\
\x30\x34\x30\x37\x39\x2c\x30\x2e\x31\x36\x36\x37\x37\x20\x30\x2e\
\x30\x36\x32\x35\x2c\x30\x2e\x32\x35\x20\x30\x2e\x31\x36\x30\x30\
\x37\x36\x2c\x30\x2e\x36\x32\x32\x31\x37\x20\x30\x2e\x33\x32\x36\
\x38\x36\x34\x2c\x31\x2e\x32\x32\x36\x32\x33\x20\x30\x2e\x35\x2c\
\x31\x2e\x38\x34\x33\x37\x35\x20\x30\x2e\x30\x36\x34\x39\x38\x2c\
\x30\x2e\x32\x32\x39\x30\x35\x20\x30\x2e\x31\x32\x30\x36\x38\x32\
\x2c\x30\x2e\x34\x35\x38\x39\x20\x30\x2e\x31\x38\x37\x35\x2c\x30\
\x2e\x36\x38\x37\x35\x20\x30\x2e\x35\x33\x39\x37\x34\x37\x2c\x31\
\x2e\x38\x36\x37\x35\x36\x20\x31\x2e\x31\x32\x34\x31\x39\x31\x2c\
\x33\x2e\x37\x31\x30\x35\x32\x20\x31\x2e\x37\x38\x31\x32\x35\x2c\
\x35\x2e\x35\x33\x31\x32\x35\x20\x30\x2e\x30\x32\x36\x39\x33\x2c\
\x30\x2e\x30\x37\x34\x20\x30\x2e\x30\x36\x36\x36\x32\x2c\x30\x2e\
\x31\x34\x34\x38\x34\x20\x30\x2e\x30\x39\x33\x37\x35\x2c\x30\x2e\
\x32\x31\x38\x37\x35\x20\x30\x2e\x32\x32\x30\x35\x35\x39\x2c\x30\
\x2e\x36\x30\x36\x31\x34\x20\x30\x2e\x34\x35\x34\x31\x39\x33\x2c\
\x31\x2e\x32\x31\x31\x39\x37\x20\x30\x2e\x36\x38\x37\x35\x2c\x31\
\x2e\x38\x31\x32\x35\x20\x30\x2e\x30\x32\x38\x39\x31\x2c\x30\x2e\
\x30\x37\x33\x38\x20\x30\x2e\x30\x36\x34\x36\x34\x2c\x30\x2e\x31\
\x34\x35\x30\x33\x20\x30\x2e\x30\x39\x33\x37\x35\x2c\x30\x2e\x32\
\x31\x38\x37\x35\x20\x31\x31\x2e\x30\x34\x35\x33\x38\x32\x2c\x32\
\x38\x2e\x32\x31\x30\x37\x33\x20\x33\x36\x2e\x30\x37\x38\x36\x32\
\x38\x2c\x35\x30\x2e\x31\x31\x34\x30\x39\x20\x36\x38\x2e\x32\x31\
\x38\x37\x34\x36\x2c\x35\x35\x2e\x37\x38\x31\x32\x35\x20\x6c\x20\
\x34\x31\x33\x2e\x36\x32\x35\x2c\x37\x32\x2e\x39\x33\x37\x35\x20\
\x63\x20\x34\x39\x2e\x31\x30\x32\x35\x37\x2c\x38\x2e\x36\x35\x38\
\x31\x31\x20\x39\x35\x2e\x35\x39\x31\x39\x32\x2c\x2d\x32\x33\x2e\
\x39\x32\x38\x36\x38\x20\x31\x30\x34\x2e\x32\x35\x2c\x2d\x37\x33\
\x2e\x30\x33\x31\x32\x35\x20\x36\x2e\x32\x31\x30\x35\x35\x2c\x2d\
\x33\x35\x2e\x32\x32\x31\x37\x35\x20\x2d\x38\x2e\x37\x37\x36\x36\
\x32\x2c\x2d\x36\x39\x2e\x30\x38\x37\x34\x35\x20\x2d\x33\x35\x2e\
\x38\x37\x35\x2c\x2d\x38\x38\x2e\x36\x32\x35\x20\x32\x37\x2e\x30\
\x38\x35\x33\x37\x2c\x2d\x31\x39\x2e\x35\x33\x39\x38\x34\x20\x34\
\x32\x2e\x30\x35\x32\x37\x33\x2c\x2d\x35\x33\x2e\x34\x31\x32\x32\
\x20\x33\x35\x2e\x38\x34\x33\x37\x35\x2c\x2d\x38\x38\x2e\x36\x32\
\x35\x20\x2d\x36\x2e\x31\x39\x39\x31\x2c\x2d\x33\x35\x2e\x31\x35\
\x36\x38\x35\x20\x2d\x33\x31\x2e\x37\x38\x30\x34\x32\x2c\x2d\x36\
\x31\x2e\x38\x36\x30\x39\x20\x2d\x36\x33\x2e\x38\x34\x33\x37\x35\
\x2c\x2d\x37\x31\x20\x31\x38\x2e\x37\x31\x31\x39\x37\x2c\x2d\x32\
\x37\x2e\x36\x31\x35\x32\x20\x32\x31\x2e\x32\x30\x31\x39\x33\x2c\
\x2d\x36\x34\x2e\x35\x30\x36\x32\x37\x20\x33\x2e\x33\x34\x33\x37\
\x35\x2c\x2d\x39\x35\x2e\x34\x33\x37\x35\x20\x2d\x31\x37\x2e\x38\
\x37\x33\x37\x35\x2c\x2d\x33\x30\x2e\x39\x35\x38\x32\x34\x20\x2d\
\x35\x31\x2e\x31\x33\x36\x38\x39\x2c\x2d\x34\x37\x2e\x32\x37\x36\
\x20\x2d\x38\x34\x2e\x34\x33\x37\x35\x2c\x2d\x34\x34\x2e\x38\x34\
\x33\x37\x35\x20\x38\x2e\x31\x35\x39\x35\x39\x2c\x2d\x33\x32\x2e\
\x33\x36\x31\x37\x38\x20\x2d\x32\x2e\x31\x32\x36\x39\x36\x2c\x2d\
\x36\x37\x2e\x39\x30\x36\x32\x39\x20\x2d\x32\x39\x2e\x35\x2c\x2d\
\x39\x30\x2e\x38\x37\x35\x20\x2d\x31\x37\x2e\x33\x30\x37\x30\x38\
\x2c\x2d\x31\x34\x2e\x35\x32\x32\x33\x36\x20\x2d\x33\x38\x2e\x33\
\x39\x32\x35\x36\x2c\x2d\x32\x31\x2e\x34\x34\x36\x33\x36\x20\x2d\
\x35\x39\x2e\x32\x35\x2c\x2d\x32\x31\x2e\x31\x32\x35\x20\x7a\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x72\x65\
\x63\x74\x33\x39\x35\x34\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\
\x69\x78\x28\x30\x2e\x30\x39\x35\x37\x30\x38\x30\x38\x2c\x30\x2c\
\x30\x2c\x30\x2e\x30\x39\x35\x37\x30\x38\x30\x38\x2c\x2d\x31\x36\
\x2e\x39\x31\x38\x39\x31\x2c\x36\x36\x31\x2e\x37\x37\x37\x33\x32\
\x29\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x72\x65\x63\
\x74\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x72\x79\x3d\x22\x38\
\x2e\x36\x31\x33\x37\x31\x39\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x79\x3d\x22\x34\x34\x33\x2e\x38\x31\x31\x31\x39\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x78\x3d\x22\x2d\x35\x35\x38\
\x2e\x36\x36\x34\x39\x32\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x68\x65\x69\x67\x68\x74\x3d\x22\x31\x37\x2e\x32\x32\x37\x34\
\x33\x38\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x77\x69\x64\
\x74\x68\x3d\x22\x35\x37\x2e\x34\x32\x34\x37\x37\x34\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x72\x65\x63\x74\
\x33\x38\x30\x36\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\
\x74\x79\x6c\x65\x3d\x22\x66\x69\x6c\x6c\x3a\x23\x65\x36\x65\x36\
\x65\x36\x3b\x66\x69\x6c\x6c\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\
\x31\x3b\x73\x74\x72\x6f\x6b\x65\x3a\x23\x66\x66\x66\x66\x66\x66\
\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x77\x69\x64\x74\x68\x3a\x31\x2e\
\x39\x39\x33\x35\x32\x35\x37\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\
\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\x6e\x64\x3b\x73\x74\
\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\x69\x6d\x69\x74\x3a\
\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\x61\x63\x69\x74\x79\
\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x61\x72\
\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\x2d\
\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\x30\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\
\x3d\x22\x6d\x61\x74\x72\x69\x78\x28\x30\x2e\x36\x34\x32\x37\x38\
\x37\x36\x33\x2c\x2d\x30\x2e\x37\x36\x36\x30\x34\x34\x34\x33\x2c\
\x30\x2e\x37\x36\x36\x30\x34\x34\x34\x33\x2c\x30\x2e\x36\x34\x32\
\x37\x38\x37\x36\x33\x2c\x30\x2c\x30\x29\x22\x20\x2f\x3e\x0a\x20\
\x20\x20\x20\x20\x20\x3c\x70\x61\x74\x68\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x6f\x70\x61\x63\x69\
\x74\x79\x3a\x30\x2e\x36\x3b\x66\x69\x6c\x6c\x3a\x6e\x6f\x6e\x65\
\x3b\x73\x74\x72\x6f\x6b\x65\x3a\x23\x30\x30\x30\x30\x30\x30\x3b\
\x73\x74\x72\x6f\x6b\x65\x2d\x77\x69\x64\x74\x68\x3a\x32\x3b\x73\
\x74\x72\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\
\x75\x6e\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\
\x6c\x69\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\
\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\
\x64\x61\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\
\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\
\x3a\x30\x3b\x66\x69\x6c\x74\x65\x72\x3a\x75\x72\x6c\x28\x23\x66\
\x69\x6c\x74\x65\x72\x34\x31\x32\x32\x29\x22\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x64\x3d\x22\x6d\x20\x35\x38\x2e\x37\x36\x32\
\x37\x35\x36\x2c\x34\x34\x37\x2e\x37\x31\x36\x32\x39\x20\x63\x20\
\x2d\x34\x36\x2e\x36\x36\x36\x30\x31\x32\x2c\x32\x36\x2e\x39\x34\
\x32\x36\x33\x20\x2d\x36\x32\x2e\x36\x33\x30\x31\x31\x31\x2c\x38\
\x36\x2e\x35\x32\x31\x34\x36\x20\x2d\x33\x35\x2e\x36\x38\x37\x34\
\x37\x36\x2c\x31\x33\x33\x2e\x31\x38\x37\x34\x38\x20\x32\x36\x2e\
\x39\x34\x32\x36\x33\x35\x2c\x34\x36\x2e\x36\x36\x36\x30\x31\x20\
\x38\x36\x2e\x35\x32\x31\x34\x36\x2c\x36\x32\x2e\x36\x33\x30\x31\
\x31\x20\x31\x33\x33\x2e\x31\x38\x37\x34\x38\x2c\x33\x35\x2e\x36\
\x38\x37\x34\x37\x20\x6c\x20\x33\x36\x33\x2e\x37\x33\x30\x36\x36\
\x2c\x2d\x32\x31\x30\x20\x63\x20\x34\x36\x2e\x36\x36\x36\x30\x32\
\x2c\x2d\x32\x36\x2e\x39\x34\x32\x36\x33\x20\x36\x32\x2e\x36\x33\
\x30\x31\x32\x2c\x2d\x38\x36\x2e\x35\x32\x31\x34\x36\x20\x33\x35\
\x2e\x36\x38\x37\x34\x38\x2c\x2d\x31\x33\x33\x2e\x31\x38\x37\x34\
\x37\x20\x2d\x32\x36\x2e\x39\x34\x32\x36\x33\x2c\x2d\x34\x36\x2e\
\x36\x36\x36\x30\x32\x20\x2d\x38\x36\x2e\x35\x32\x31\x34\x36\x2c\
\x2d\x36\x32\x2e\x36\x33\x30\x31\x32\x20\x2d\x31\x33\x33\x2e\x31\
\x38\x37\x34\x38\x2c\x2d\x33\x35\x2e\x36\x38\x37\x34\x38\x20\x6c\
\x20\x2d\x33\x36\x33\x2e\x37\x33\x30\x36\x36\x34\x2c\x32\x31\x30\
\x20\x7a\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\
\x22\x72\x65\x63\x74\x34\x31\x30\x38\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x6e\x6f\x64\
\x65\x74\x79\x70\x65\x73\x3d\x22\x63\x73\x63\x63\x73\x63\x63\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\
\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\x69\x78\x28\x30\x2e\x30\x39\
\x35\x37\x30\x38\x30\x38\x2c\x30\x2c\x30\x2c\x30\x2e\x30\x39\x35\
\x37\x30\x38\x30\x38\x2c\x2d\x31\x37\x2e\x32\x37\x32\x34\x36\x34\
\x2c\x36\x36\x31\x2e\x32\x34\x36\x39\x38\x29\x22\x20\x2f\x3e\x0a\
\x20\x20\x20\x20\x20\x20\x3c\x72\x65\x63\x74\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x72\x79\x3d\x22\x38\x2e\x36\x31\x33\x37\x32\
\x38\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x79\x3d\x22\
\x36\x30\x34\x2e\x36\x36\x30\x37\x37\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x78\x3d\x22\x2d\x33\x37\x30\x2e\x37\x34\x39\x38\
\x32\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x68\x65\x69\x67\
\x68\x74\x3d\x22\x31\x37\x2e\x32\x32\x37\x34\x35\x37\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x77\x69\x64\x74\x68\x3d\x22\x35\
\x37\x2e\x34\x32\x34\x38\x34\x37\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x69\x64\x3d\x22\x72\x65\x63\x74\x33\x38\x30\x34\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\
\x22\x66\x69\x6c\x6c\x3a\x23\x30\x30\x30\x30\x66\x66\x3b\x66\x69\
\x6c\x6c\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\
\x6f\x6b\x65\x3a\x23\x66\x66\x66\x66\x66\x66\x3b\x73\x74\x72\x6f\
\x6b\x65\x2d\x77\x69\x64\x74\x68\x3a\x31\x2e\x39\x39\x33\x35\x32\
\x35\x37\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\
\x61\x70\x3a\x72\x6f\x75\x6e\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\
\x6d\x69\x74\x65\x72\x6c\x69\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\
\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\
\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\
\x66\x66\x73\x65\x74\x3a\x30\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x6d\x61\x74\
\x72\x69\x78\x28\x30\x2e\x38\x36\x36\x30\x32\x35\x34\x2c\x2d\x30\
\x2e\x35\x2c\x30\x2e\x35\x2c\x30\x2e\x38\x36\x36\x30\x32\x35\x34\
\x2c\x30\x2c\x30\x29\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\
\x3c\x70\x61\x74\x68\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\
\x74\x79\x6c\x65\x3d\x22\x6f\x70\x61\x63\x69\x74\x79\x3a\x30\x2e\
\x36\x3b\x66\x69\x6c\x6c\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\
\x6b\x65\x3a\x23\x30\x30\x30\x30\x30\x30\x3b\x73\x74\x72\x6f\x6b\
\x65\x2d\x77\x69\x64\x74\x68\x3a\x32\x3b\x73\x74\x72\x6f\x6b\x65\
\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\x6e\x64\x3b\x73\
\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\x69\x6d\x69\x74\
\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\x61\x63\x69\x74\
\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x61\
\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\
\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\x30\x3b\x66\x69\
\x6c\x74\x65\x72\x3a\x75\x72\x6c\x28\x23\x66\x69\x6c\x74\x65\x72\
\x34\x31\x32\x36\x29\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x64\x3d\x22\x6d\x20\x39\x30\x2e\x35\x33\x33\x39\x31\x2c\x34\x33\
\x36\x2e\x31\x33\x39\x36\x31\x20\x63\x20\x2d\x35\x33\x2e\x30\x36\
\x36\x36\x35\x35\x2c\x39\x2e\x33\x35\x37\x30\x37\x20\x2d\x38\x38\
\x2e\x34\x34\x35\x31\x34\x36\x2c\x35\x39\x2e\x38\x38\x32\x38\x32\
\x20\x2d\x37\x39\x2e\x30\x38\x38\x30\x37\x33\x2c\x31\x31\x32\x2e\
\x39\x34\x39\x34\x35\x20\x39\x2e\x33\x35\x37\x30\x37\x38\x2c\x35\
\x33\x2e\x30\x36\x36\x36\x35\x20\x35\x39\x2e\x38\x38\x32\x38\x30\
\x33\x2c\x38\x38\x2e\x34\x34\x35\x31\x37\x20\x31\x31\x32\x2e\x39\
\x34\x39\x34\x35\x33\x2c\x37\x39\x2e\x30\x38\x38\x30\x37\x20\x6c\
\x20\x34\x31\x33\x2e\x36\x31\x39\x32\x37\x2c\x2d\x37\x32\x2e\x39\
\x33\x32\x32\x31\x20\x63\x20\x35\x33\x2e\x30\x36\x36\x36\x35\x2c\
\x2d\x39\x2e\x33\x35\x37\x30\x37\x20\x38\x38\x2e\x34\x34\x35\x31\
\x34\x2c\x2d\x35\x39\x2e\x38\x38\x32\x37\x37\x20\x37\x39\x2e\x30\
\x38\x38\x30\x37\x2c\x2d\x31\x31\x32\x2e\x39\x34\x39\x34\x35\x20\
\x2d\x39\x2e\x33\x35\x37\x30\x37\x2c\x2d\x35\x33\x2e\x30\x36\x36\
\x36\x35\x20\x2d\x35\x39\x2e\x38\x38\x32\x37\x39\x2c\x2d\x38\x38\
\x2e\x34\x34\x35\x31\x35\x20\x2d\x31\x31\x32\x2e\x39\x34\x39\x34\
\x35\x2c\x2d\x37\x39\x2e\x30\x38\x38\x30\x37\x20\x4c\x20\x39\x30\
\x2e\x35\x33\x33\x39\x31\x2c\x34\x33\x36\x2e\x31\x33\x39\x36\x31\
\x20\x7a\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\
\x22\x72\x65\x63\x74\x34\x30\x39\x34\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x6e\x6f\x64\
\x65\x74\x79\x70\x65\x73\x3d\x22\x63\x73\x63\x63\x73\x63\x63\x22\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\
\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\x69\x78\x28\x30\x2e\x30\x39\
\x35\x37\x30\x38\x30\x38\x2c\x30\x2c\x30\x2c\x30\x2e\x30\x39\x35\
\x37\x30\x38\x30\x38\x2c\x2d\x31\x37\x2e\x32\x37\x32\x34\x36\x34\
\x2c\x36\x36\x31\x2e\x32\x34\x36\x39\x38\x29\x22\x20\x2f\x3e\x0a\
\x20\x20\x20\x20\x20\x20\x3c\x72\x65\x63\x74\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x72\x79\x3d\x22\x38\x2e\x36\x31\x33\x37\x32\
\x38\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x79\x3d\x22\
\x36\x39\x31\x2e\x35\x33\x31\x39\x32\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x78\x3d\x22\x2d\x31\x33\x39\x2e\x31\x36\x33\x32\
\x31\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x68\x65\x69\x67\
\x68\x74\x3d\x22\x31\x37\x2e\x32\x32\x37\x34\x35\x37\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x77\x69\x64\x74\x68\x3d\x22\x35\
\x37\x2e\x34\x32\x34\x38\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x69\x64\x3d\x22\x72\x65\x63\x74\x33\x38\x30\x32\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\
\x66\x69\x6c\x6c\x3a\x23\x66\x66\x30\x30\x30\x30\x3b\x66\x69\x6c\
\x6c\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\
\x6b\x65\x3a\x23\x66\x66\x66\x66\x66\x66\x3b\x73\x74\x72\x6f\x6b\
\x65\x2d\x77\x69\x64\x74\x68\x3a\x31\x2e\x39\x39\x33\x35\x32\x35\
\x37\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\x61\
\x70\x3a\x72\x6f\x75\x6e\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6d\
\x69\x74\x65\x72\x6c\x69\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\x6f\
\x6b\x65\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x64\x61\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\x6f\
\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\x66\
\x66\x73\x65\x74\x3a\x30\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\
\x69\x78\x28\x30\x2e\x39\x38\x34\x38\x30\x37\x37\x37\x2c\x2d\x30\
\x2e\x31\x37\x33\x36\x34\x38\x30\x39\x2c\x30\x2e\x31\x37\x33\x36\
\x34\x38\x30\x39\x2c\x30\x2e\x39\x38\x34\x38\x30\x37\x37\x37\x2c\
\x30\x2c\x30\x29\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\
\x70\x61\x74\x68\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\
\x79\x6c\x65\x3d\x22\x6f\x70\x61\x63\x69\x74\x79\x3a\x30\x2e\x36\
\x3b\x66\x69\x6c\x6c\x3a\x23\x66\x66\x66\x66\x66\x66\x3b\x66\x69\
\x6c\x6c\x2d\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\
\x6f\x6b\x65\x3a\x23\x30\x30\x30\x30\x30\x30\x3b\x73\x74\x72\x6f\
\x6b\x65\x2d\x77\x69\x64\x74\x68\x3a\x32\x3b\x73\x74\x72\x6f\x6b\
\x65\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\x6e\x64\x3b\
\x73\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\x69\x6d\x69\
\x74\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\x61\x63\x69\
\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\
\x61\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\
\x65\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\x30\x3b\x66\
\x69\x6c\x74\x65\x72\x3a\x75\x72\x6c\x28\x23\x66\x69\x6c\x74\x65\
\x72\x34\x31\x33\x30\x29\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x64\x3d\x22\x6d\x20\x31\x30\x37\x2e\x31\x34\x33\x35\x33\x2c\
\x34\x33\x34\x2e\x37\x39\x35\x39\x31\x20\x63\x20\x2d\x34\x36\x2e\
\x33\x35\x35\x39\x32\x2c\x30\x2e\x30\x39\x33\x37\x20\x2d\x38\x37\
\x2e\x33\x35\x33\x38\x33\x36\x2c\x33\x33\x2e\x33\x33\x31\x32\x32\
\x20\x2d\x39\x35\x2e\x36\x38\x37\x34\x39\x36\x2c\x38\x30\x2e\x35\
\x39\x33\x37\x35\x20\x2d\x39\x2e\x33\x35\x37\x30\x39\x33\x2c\x35\
\x33\x2e\x30\x36\x36\x37\x20\x32\x36\x2e\x30\x32\x37\x30\x34\x35\
\x2c\x31\x30\x33\x2e\x35\x38\x30\x34\x34\x20\x37\x39\x2e\x30\x39\
\x33\x37\x34\x36\x2c\x31\x31\x32\x2e\x39\x33\x37\x35\x20\x6c\x20\
\x34\x31\x33\x2e\x36\x32\x35\x2c\x37\x32\x2e\x39\x33\x37\x35\x20\
\x63\x20\x35\x33\x2e\x30\x36\x36\x37\x2c\x39\x2e\x33\x35\x37\x31\
\x20\x31\x30\x33\x2e\x35\x38\x30\x33\x39\x2c\x2d\x32\x36\x2e\x30\
\x32\x37\x30\x35\x20\x31\x31\x32\x2e\x39\x33\x37\x35\x2c\x2d\x37\
\x39\x2e\x30\x39\x33\x37\x35\x20\x39\x2e\x33\x35\x37\x30\x39\x2c\
\x2d\x35\x33\x2e\x30\x36\x36\x36\x37\x20\x2d\x32\x36\x2e\x30\x32\
\x37\x30\x36\x2c\x2d\x31\x30\x33\x2e\x35\x38\x30\x34\x31\x20\x2d\
\x37\x39\x2e\x30\x39\x33\x37\x35\x2c\x2d\x31\x31\x32\x2e\x39\x33\
\x37\x35\x20\x6c\x20\x2d\x34\x31\x33\x2e\x35\x39\x33\x37\x35\x2c\
\x2d\x37\x32\x2e\x39\x33\x37\x35\x20\x63\x20\x2d\x35\x2e\x38\x30\
\x34\x31\x37\x2c\x2d\x31\x2e\x30\x32\x33\x34\x33\x20\x2d\x31\x31\
\x2e\x35\x38\x38\x34\x32\x2c\x2d\x31\x2e\x35\x31\x31\x35\x31\x20\
\x2d\x31\x37\x2e\x32\x38\x31\x32\x35\x2c\x2d\x31\x2e\x35\x20\x7a\
\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x72\
\x65\x63\x74\x34\x30\x33\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x6e\x6f\x64\x65\x74\
\x79\x70\x65\x73\x3d\x22\x63\x73\x63\x63\x73\x63\x63\x63\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\
\x72\x6d\x3d\x22\x6d\x61\x74\x72\x69\x78\x28\x30\x2e\x30\x39\x35\
\x37\x30\x38\x30\x38\x2c\x30\x2c\x30\x2c\x30\x2e\x30\x39\x35\x37\
\x30\x38\x30\x38\x2c\x2d\x31\x37\x2e\x32\x37\x32\x34\x36\x34\x2c\
\x36\x36\x31\x2e\x32\x34\x36\x39\x38\x29\x22\x20\x2f\x3e\x0a\x20\
\x20\x20\x20\x20\x20\x3c\x72\x65\x63\x74\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x66\x69\x6c\x6c\x3a\
\x23\x66\x66\x66\x66\x30\x30\x3b\x66\x69\x6c\x6c\x2d\x6f\x70\x61\
\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x3a\x23\x66\
\x66\x66\x66\x66\x66\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x77\x69\x64\
\x74\x68\x3a\x31\x2e\x39\x39\x33\x35\x32\x35\x37\x34\x3b\x73\x74\
\x72\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\
\x6e\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\
\x69\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\
\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\
\x61\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\
\x72\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\
\x30\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\
\x72\x65\x63\x74\x33\x30\x31\x34\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x77\x69\x64\x74\x68\x3d\x22\x35\x37\x2e\x34\x32\x34\
\x38\x35\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x68\x65\x69\
\x67\x68\x74\x3d\x22\x31\x37\x2e\x32\x32\x37\x34\x38\x39\x22\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x78\x3d\x22\x31\x30\x38\x2e\
\x31\x37\x38\x38\x36\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x79\x3d\x22\x36\x39\x33\x2e\x39\x37\x32\x34\x31\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x72\x79\x3d\x22\x38\x2e\x36\x31\x33\
\x37\x34\x34\x37\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\
\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\x69\x78\
\x28\x30\x2e\x39\x38\x34\x38\x30\x37\x37\x35\x2c\x30\x2e\x31\x37\
\x33\x36\x34\x38\x31\x39\x2c\x2d\x30\x2e\x31\x37\x33\x36\x34\x38\
\x31\x39\x2c\x30\x2e\x39\x38\x34\x38\x30\x37\x37\x35\x2c\x30\x2c\
\x30\x29\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\x67\x0a\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x67\x34\x30\
\x32\x39\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\x72\x61\
\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x6d\x61\x74\x72\x69\x78\x28\x30\
\x2e\x30\x37\x30\x37\x31\x30\x38\x34\x2c\x30\x2c\x30\x2c\x30\x2e\
\x30\x37\x30\x37\x31\x30\x38\x34\x2c\x2d\x31\x35\x2e\x35\x31\x31\
\x36\x34\x34\x2c\x36\x37\x36\x2e\x31\x34\x31\x33\x36\x29\x22\x3e\
\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x3c\x70\x61\x74\x68\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\
\x64\x69\x3a\x74\x79\x70\x65\x3d\x22\x61\x72\x63\x22\x0a\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\
\x6f\x70\x61\x63\x69\x74\x79\x3a\x30\x2e\x34\x3b\x66\x69\x6c\x6c\
\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\x6f\x6b\x65\x3a\x23\x30\x30\
\x30\x30\x30\x30\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x77\x69\x64\x74\
\x68\x3a\x32\x2e\x37\x30\x37\x30\x32\x37\x34\x34\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x6c\x69\x6e\x65\x63\x61\x70\x3a\x72\x6f\x75\x6e\
\x64\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6d\x69\x74\x65\x72\x6c\x69\
\x6d\x69\x74\x3a\x34\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x6f\x70\x61\
\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\x2d\x64\x61\
\x73\x68\x61\x72\x72\x61\x79\x3a\x6e\x6f\x6e\x65\x3b\x73\x74\x72\
\x6f\x6b\x65\x2d\x64\x61\x73\x68\x6f\x66\x66\x73\x65\x74\x3a\x30\
\x3b\x66\x69\x6c\x74\x65\x72\x3a\x75\x72\x6c\x28\x23\x66\x69\x6c\
\x74\x65\x72\x34\x31\x34\x36\x29\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x69\x64\x3d\x22\x70\x61\x74\x68\x34\x30\x30\
\x37\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x6f\
\x64\x69\x70\x6f\x64\x69\x3a\x63\x78\x3d\x22\x31\x34\x35\x2e\x34\
\x36\x31\x39\x36\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x63\x79\x3d\x22\x34\x37\
\x39\x2e\x32\x38\x31\x36\x38\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x72\x78\x3d\
\x22\x33\x36\x2e\x37\x38\x37\x34\x34\x39\x22\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\
\x72\x79\x3d\x22\x33\x36\x2e\x37\x38\x37\x34\x34\x39\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x64\x3d\x22\x6d\x20\x31\
\x38\x32\x2e\x32\x34\x39\x34\x31\x2c\x34\x37\x39\x2e\x32\x38\x31\
\x36\x38\x20\x63\x20\x30\x2c\x32\x30\x2e\x33\x31\x37\x31\x34\x20\
\x2d\x31\x36\x2e\x34\x37\x30\x33\x2c\x33\x36\x2e\x37\x38\x37\x34\
\x35\x20\x2d\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x33\x36\x2e\x37\
\x38\x37\x34\x35\x20\x2d\x32\x30\x2e\x33\x31\x37\x31\x35\x2c\x30\
\x20\x2d\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x2d\x31\x36\x2e\x34\
\x37\x30\x33\x31\x20\x2d\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x2d\
\x33\x36\x2e\x37\x38\x37\x34\x35\x20\x30\x2c\x2d\x32\x30\x2e\x33\
\x31\x37\x31\x35\x20\x31\x36\x2e\x34\x37\x30\x33\x2c\x2d\x33\x36\
\x2e\x37\x38\x37\x34\x35\x20\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\
\x2d\x33\x36\x2e\x37\x38\x37\x34\x35\x20\x32\x30\x2e\x33\x31\x37\
\x31\x35\x2c\x30\x20\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x31\x36\
\x2e\x34\x37\x30\x33\x20\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x33\
\x36\x2e\x37\x38\x37\x34\x35\x20\x7a\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x3d\
\x22\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x28\x2d\x32\x31\x2e\x34\
\x31\x38\x39\x36\x36\x2c\x33\x32\x2e\x33\x32\x37\x31\x36\x31\x29\
\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x3c\x70\x61\
\x74\x68\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x74\x72\
\x61\x6e\x73\x66\x6f\x72\x6d\x3d\x22\x74\x72\x61\x6e\x73\x6c\x61\
\x74\x65\x28\x2d\x32\x31\x2e\x34\x31\x38\x39\x36\x36\x2c\x33\x32\
\x2e\x33\x32\x37\x31\x36\x31\x29\x22\x0a\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x64\x3d\x22\x6d\x20\x31\x38\x32\x2e\x32\x34\
\x39\x34\x31\x2c\x34\x37\x39\x2e\x32\x38\x31\x36\x38\x20\x63\x20\
\x30\x2c\x32\x30\x2e\x33\x31\x37\x31\x34\x20\x2d\x31\x36\x2e\x34\
\x37\x30\x33\x2c\x33\x36\x2e\x37\x38\x37\x34\x35\x20\x2d\x33\x36\
\x2e\x37\x38\x37\x34\x35\x2c\x33\x36\x2e\x37\x38\x37\x34\x35\x20\
\x2d\x32\x30\x2e\x33\x31\x37\x31\x35\x2c\x30\x20\x2d\x33\x36\x2e\
\x37\x38\x37\x34\x35\x2c\x2d\x31\x36\x2e\x34\x37\x30\x33\x31\x20\
\x2d\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x2d\x33\x36\x2e\x37\x38\
\x37\x34\x35\x20\x30\x2c\x2d\x32\x30\x2e\x33\x31\x37\x31\x35\x20\
\x31\x36\x2e\x34\x37\x30\x33\x2c\x2d\x33\x36\x2e\x37\x38\x37\x34\
\x35\x20\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x2d\x33\x36\x2e\x37\
\x38\x37\x34\x35\x20\x32\x30\x2e\x33\x31\x37\x31\x35\x2c\x30\x20\
\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x31\x36\x2e\x34\x37\x30\x33\
\x20\x33\x36\x2e\x37\x38\x37\x34\x35\x2c\x33\x36\x2e\x37\x38\x37\
\x34\x35\x20\x7a\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x72\x79\x3d\x22\x33\x36\
\x2e\x37\x38\x37\x34\x34\x39\x22\x0a\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x72\x78\x3d\
\x22\x33\x36\x2e\x37\x38\x37\x34\x34\x39\x22\x0a\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\
\x63\x79\x3d\x22\x34\x37\x39\x2e\x32\x38\x31\x36\x38\x22\x0a\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x73\x6f\x64\x69\x70\x6f\
\x64\x69\x3a\x63\x78\x3d\x22\x31\x34\x35\x2e\x34\x36\x31\x39\x36\
\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x69\x64\x3d\
\x22\x70\x61\x74\x68\x33\x39\x37\x31\x22\x0a\x20\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x73\x74\x79\x6c\x65\x3d\x22\x66\x69\x6c\
\x6c\x3a\x75\x72\x6c\x28\x23\x72\x61\x64\x69\x61\x6c\x47\x72\x61\
\x64\x69\x65\x6e\x74\x34\x30\x33\x33\x29\x3b\x66\x69\x6c\x6c\x2d\
\x6f\x70\x61\x63\x69\x74\x79\x3a\x31\x3b\x73\x74\x72\x6f\x6b\x65\
\x3a\x6e\x6f\x6e\x65\x22\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\
\x20\x20\x73\x6f\x64\x69\x70\x6f\x64\x69\x3a\x74\x79\x70\x65\x3d\
\x22\x61\x72\x63\x22\x20\x2f\x3e\x0a\x20\x20\x20\x20\x20\x20\x3c\
\x2f\x67\x3e\x0a\x20\x20\x20\x20\x3c\x2f\x67\x3e\x0a\x20\x20\x3c\
\x2f\x67\x3e\x0a\x3c\x2f\x73\x76\x67\x3e\x0a\
"

qt_resource_name = "\
\x00\x10\
\x04\xe6\xf8\x27\
\x00\x73\
\x00\x77\x00\x61\x00\x74\x00\x63\x00\x68\x00\x62\x00\x6f\x00\x6f\x00\x6b\x00\x65\x00\x72\x00\x2e\x00\x73\x00\x76\x00\x67\
"

qt_resource_struct = "\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
"

def qInitResources():
    qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
